@@ -1,10 +1,13 @@
 """ Action Queue Process Command Definition """
 
-import requests
+from starlette import status
 
-from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
+from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import ActionQueue
 
+from ..contracts.dto.request_status_codes import RequestStatusCodes
+from ..contracts.dto.wrapped_request import WrappedRequest
+from ..contracts.request_verb import RequestVerb
 from .abstract_command import AbstractCommand
 
 
@@ -19,7 +22,7 @@ class ActionQueueProcessCommand(AbstractCommand):
         Executes the command.
     """
 
-    def execute(self, request: ActionQueue, headers: dict[str, str]) -> None:
+    def execute(self, request: ActionQueue) -> None:
         """
         Executes the command.
 
@@ -27,13 +30,12 @@ class ActionQueueProcessCommand(AbstractCommand):
         ----------
         request: ActionQueue
             The action queue to process.
-        headers: dict[str, str]
-            Request headers
         """
 
-        requests.post(
+        request: WrappedRequest = WrappedRequest(
+            verb=RequestVerb.POST,
             url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/world/queue",
+            statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
             data=request.json(by_alias=True),
-            headers=headers,
-            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
+        self.wrapped_request(request=request)
