@@ -3,11 +3,11 @@
 from starlette import status
 
 from rowantree.common.sdk import demand_env_var
-from rowantree.contracts import UserFeatures
 
 from ...contracts.dto.request_status_codes import RequestStatusCodes
 from ...contracts.dto.wrapped_request import WrappedRequest
 from ...contracts.request_verb import RequestVerb
+from ...contracts.responses.features_get import FeaturesGetResponse
 from ..abstract_command import AbstractCommand
 
 
@@ -18,11 +18,11 @@ class UserFeaturesGetCommand(AbstractCommand):
 
     Methods
     -------
-    execute(self, user_guid: str) -> UserFeatures
+    execute(self, user_guid: str) -> FeaturesGetResponse
         Executes the command.
     """
 
-    def execute(self, user_guid: str) -> UserFeatures:
+    def execute(self, user_guid: str) -> FeaturesGetResponse:
         """
         Executes the command.
 
@@ -33,7 +33,7 @@ class UserFeaturesGetCommand(AbstractCommand):
 
         Returns
         -------
-        user_features: UserFeatures
+        user_features: FeaturesGetResponse
             A unique list of user features.
         """
 
@@ -43,4 +43,4 @@ class UserFeaturesGetCommand(AbstractCommand):
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
         response: dict = self.wrapped_request(request=request)
-        return UserFeatures.parse_obj(response)
+        return FeaturesGetResponse.parse_obj(response)
