@@ -3,11 +3,11 @@
 from starlette import status
 
 from rowantree.common.sdk import demand_env_var
-from rowantree.contracts import UserIncomes
 
 from ...contracts.dto.request_status_codes import RequestStatusCodes
 from ...contracts.dto.wrapped_request import WrappedRequest
 from ...contracts.request_verb import RequestVerb
+from ...contracts.responses.income_get import UserIncomeGetResponse
 from ..abstract_command import AbstractCommand
 
 
@@ -18,11 +18,11 @@ class UserIncomeGetCommand(AbstractCommand):
 
     Methods
     -------
-    execute(self, user_guid: str) -> UserIncomes
+    execute(self, user_guid: str) -> UserIncomeGetResponse
         Executes the command.
     """
 
-    def execute(self, user_guid: str) -> UserIncomes:
+    def execute(self, user_guid: str) -> UserIncomeGetResponse:
         """
         Executes the command.
 
@@ -33,7 +33,7 @@ class UserIncomeGetCommand(AbstractCommand):
 
         Returns
         -------
-        user_incomes: UserIncomes
+        user_incomes: UserIncomeGetResponse
             A (unique) list of user incomes.
         """
 
@@ -43,4 +43,4 @@ class UserIncomeGetCommand(AbstractCommand):
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
         response: dict = self.wrapped_request(request=request)
-        return UserIncomes.parse_obj(response)
+        return UserIncomeGetResponse.parse_obj(response)
