@@ -3,11 +3,11 @@
 from starlette import status
 
 from rowantree.common.sdk import demand_env_var
-from rowantree.contracts import UserStores
 
 from ...contracts.dto.request_status_codes import RequestStatusCodes
 from ...contracts.dto.wrapped_request import WrappedRequest
 from ...contracts.request_verb import RequestVerb
+from ...contracts.responses.stores_get import StoresGetResponse
 from ..abstract_command import AbstractCommand
 
 
@@ -18,11 +18,11 @@ class UserStoresGetCommand(AbstractCommand):
 
     Methods
     -------
-    execute(self, user_guid: str) -> UserStores
+    execute(self, user_guid: str) -> StoresGetResponse
         Executes the command.
     """
 
-    def execute(self, user_guid: str) -> UserStores:
+    def execute(self, user_guid: str) -> StoresGetResponse:
         """
         Gets the (unique) list of user stores.
 
@@ -33,7 +33,7 @@ class UserStoresGetCommand(AbstractCommand):
 
         Returns
         -------
-        user_stores: UserStores
+        user_stores: StoresGetResponse
             A (unique) list of user stores.
         """
 
@@ -43,4 +43,4 @@ class UserStoresGetCommand(AbstractCommand):
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
         response: dict = self.wrapped_request(request=request)
-        return UserStores.parse_obj(response)
+        return StoresGetResponse.parse_obj(response)
