@@ -3,12 +3,12 @@
 from starlette import status
 
 from rowantree.common.sdk import demand_env_var
-from rowantree.contracts import UserFeature
 
 from ...contracts.dto.request_status_codes import RequestStatusCodes
 from ...contracts.dto.wrapped_request import WrappedRequest
 from ...contracts.request_verb import RequestVerb
 from ...contracts.requests.user.transport import UserTransportRequest
+from ...contracts.responses.active_feature import ActiveFeatureResponse
 from ..abstract_command import AbstractCommand
 
 
@@ -23,7 +23,7 @@ class UserTransportCommand(AbstractCommand):
         Executes the command.
     """
 
-    def execute(self, user_guid: str, request: UserTransportRequest) -> UserFeature:
+    def execute(self, user_guid: str, request: UserTransportRequest) -> ActiveFeatureResponse:
         """
         Executes the command.
 
@@ -47,4 +47,4 @@ class UserTransportCommand(AbstractCommand):
             data=request.json(by_alias=True),
         )
         response: dict = self.wrapped_request(request=request)
-        return UserFeature.parse_obj(response)
+        return ActiveFeatureResponse.parse_obj(response)
